/*
 * Author: Andreas Alfons
 *         Vienna University of Technology
 */

#include <R.h>
#include <Rinternals.h>
#include <Rmath.h>
#include <R_ext/Random.h>

SEXP inclusionProb(SEXP prob, SEXP size);
//SEXP tille(SEXP prob, SEXP size);
